==> haskell-aeson-1.0.2.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.0.2.1
id: aeson-1.0.2.1-2ZVWrPwy6DiCTqwqKZ33yf
key: aeson-1.0.2.1-2ZVWrPwy6DiCTqwqKZ33yf
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encoding Data.Aeson.Parser Data.Aeson.Text
    Data.Aeson.Types Data.Aeson.TH Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Encode
hidden-modules: Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Internal
                Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
                Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
                Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
                Data.Aeson.Types.Internal
abi: 863db1d4f8ff60dd666595643c79fa27
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-1.0.2.1
hs-libraries: HSaeson-1.0.2.1-2ZVWrPwy6DiCTqwqKZ33yf
depends:
    attoparsec-0.13.1.0-2DLGgk6uYI0KCQbpcUzmmN base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv ghc-prim-0.5.0.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    scientific-0.3.4.11-5YFbOuzIP87JejbsC75jcv
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.0.2.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 1.0.2.1
id: aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
key: aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encoding Data.Aeson.Parser Data.Aeson.Text
    Data.Aeson.Types Data.Aeson.TH Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Encode
hidden-modules: Data.Aeson.Encoding.Builder
                Data.Aeson.Internal.Functions Data.Aeson.Parser.Internal
                Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
                Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
                Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
                Data.Aeson.Types.Internal
abi: a1dc1034b5ecbc827159c44931deb18f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-1.0.2.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-1.0.2.1
hs-libraries: HSaeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0
    dlist-0.8.0.2-GWAMmbX9rLg3tqrbOizHGv ghc-prim-0.5.0.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
